UNSUPPORTED_TYPE <- 0L
INTEGER <- 1L
DOUBLE <-  2L
BOOLEAN <- 3L
STRING <-  4L
UNSUPPORTED_STRUCTURE <- 10L
NULLTYPE  <- 11L
REFERENCE <- 12L
ATOMIC    <- 13L
VECTOR    <- 14L
MATRIX    <- 15L
EXIT          <- 100L
RESET         <- 101L
GC            <- 102L
VACANT_103    <- 103L
EVAL          <- 104L
SET           <- 105L
SET_SINGLE    <- 106L
SET_DOUBLE    <- 107L
GET           <- 108L
GET_REFERENCE <- 109L
DEF           <- 110L
INVOKE        <- 111L
SCALAP        <- 112L
EVALNAKED     <- 113L
SHUTDOWN      <- 114L
OK <- 1000L
ERROR <- 1001L
UNDEFINED_IDENTIFIER <- 1002L
CURRENT_SUPPORTED_SCALA_VERSION <- "2.12.0"
